@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from abc import ABC, abstractmethod
 from argparse import ArgumentParser
-from typing import Iterable, Union, Optional
+from typing import Iterable, Union, Optional, Callable, Any
 
 from ..context import context
 from ..phase import phases, Phase
@@ -21,6 +21,13 @@ class Command(RegistryObject, ABC):
         Check if this command allow unknown args.
         """
 
+    @property
+    @abstractmethod
+    def avoid_stdout(self):
+        """
+        Should this command avoid stdout spoiling
+        """
+
     @abstractmethod
     def execute(self):
         """
@@ -45,15 +52,21 @@ class DefaultCommand(DefaultRegistryObject, Command):
     """
 
     def __init__(self, name: str, description: str = None, parent: Optional[Union[Command, str]] = None,
-                 allow_unknown_args=False):
+                 allow_unknown_args=False, before_execute: Optional[Callable[[], Any]] = None, avoid_stdout=False):
         super().__init__(name, description)
+        self.before_execute = before_execute
         self._parent = parent
         self._allow_unknown_args = allow_unknown_args
+        self._avoid_stdout = avoid_stdout
 
     @property
     def allow_unknown_args(self):
         return self._allow_unknown_args
 
+    @property
+    def avoid_stdout(self):
+        return self._avoid_stdout
+
     @property
     def parent(self) -> Optional[Command]:
         """
@@ -76,6 +89,9 @@ class DefaultCommand(DefaultRegistryObject, Command):
         """
         Execute the command.
         """
+        if self.before_execute:
+            self.before_execute()
+
         if self.parent:
             self.parent.execute()
 
@@ -87,8 +103,9 @@ class LifecycleCommand(DefaultCommand):
     """
 
     def __init__(self, name: str, description: Union[str, None], *lifecycle: Union[str, Phase],
-                 parent: Optional[Union[Command, str]] = None):
-        super().__init__(name, description, parent)
+                 parent: Optional[Union[Command, str]] = None, before_execute: Optional[Callable[[], Any]] = None,
+                 avoid_stdout=False):
+        super().__init__(name, description, parent, before_execute=before_execute, avoid_stdout=avoid_stdout)
         self._lifecycle = list(map(lambda phase: phases.get(phase) if not isinstance(phase, Phase) else phase,
                                    lifecycle))  # type: Iterable[Phase]
         for phase in self._lifecycle:
@@ -110,6 +127,7 @@ class LifecycleWithoutHelpCommand(LifecycleCommand):
     """
     A LifecycleCommand that doesn't add --help option to it's parser.
     """
+
     def add_parser(self, subparsers):
         """
         Add command parser into given subparsers.
